@@ -31,28 +31,28 @@ from .paginator import (
     ListTagsForResourcePaginator,
 )
 from .type_defs import (
-    CreateAccountAssignmentResponseTypeDef,
-    CreatePermissionSetResponseTypeDef,
-    DeleteAccountAssignmentResponseTypeDef,
-    DescribeAccountAssignmentCreationStatusResponseTypeDef,
-    DescribeAccountAssignmentDeletionStatusResponseTypeDef,
-    DescribeInstanceAccessControlAttributeConfigurationResponseTypeDef,
-    DescribePermissionSetProvisioningStatusResponseTypeDef,
-    DescribePermissionSetResponseTypeDef,
-    GetInlinePolicyForPermissionSetResponseTypeDef,
+    CreateAccountAssignmentResponseResponseTypeDef,
+    CreatePermissionSetResponseResponseTypeDef,
+    DeleteAccountAssignmentResponseResponseTypeDef,
+    DescribeAccountAssignmentCreationStatusResponseResponseTypeDef,
+    DescribeAccountAssignmentDeletionStatusResponseResponseTypeDef,
+    DescribeInstanceAccessControlAttributeConfigurationResponseResponseTypeDef,
+    DescribePermissionSetProvisioningStatusResponseResponseTypeDef,
+    DescribePermissionSetResponseResponseTypeDef,
+    GetInlinePolicyForPermissionSetResponseResponseTypeDef,
     InstanceAccessControlAttributeConfigurationTypeDef,
-    ListAccountAssignmentCreationStatusResponseTypeDef,
-    ListAccountAssignmentDeletionStatusResponseTypeDef,
-    ListAccountAssignmentsResponseTypeDef,
-    ListAccountsForProvisionedPermissionSetResponseTypeDef,
-    ListInstancesResponseTypeDef,
-    ListManagedPoliciesInPermissionSetResponseTypeDef,
-    ListPermissionSetProvisioningStatusResponseTypeDef,
-    ListPermissionSetsProvisionedToAccountResponseTypeDef,
-    ListPermissionSetsResponseTypeDef,
-    ListTagsForResourceResponseTypeDef,
+    ListAccountAssignmentCreationStatusResponseResponseTypeDef,
+    ListAccountAssignmentDeletionStatusResponseResponseTypeDef,
+    ListAccountAssignmentsResponseResponseTypeDef,
+    ListAccountsForProvisionedPermissionSetResponseResponseTypeDef,
+    ListInstancesResponseResponseTypeDef,
+    ListManagedPoliciesInPermissionSetResponseResponseTypeDef,
+    ListPermissionSetProvisioningStatusResponseResponseTypeDef,
+    ListPermissionSetsProvisionedToAccountResponseResponseTypeDef,
+    ListPermissionSetsResponseResponseTypeDef,
+    ListTagsForResourceResponseResponseTypeDef,
     OperationStatusFilterTypeDef,
-    ProvisionPermissionSetResponseTypeDef,
+    ProvisionPermissionSetResponseResponseTypeDef,
     TagTypeDef,
 )
 
@@ -86,7 +86,7 @@ class Exceptions:
 
 class SSOAdminClient:
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html)
     """
 
@@ -97,13 +97,17 @@ class SSOAdminClient:
         self, *, InstanceArn: str, PermissionSetArn: str, ManagedPolicyArn: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.attach_managed_policy_to_permission_set)
+        Attaches an IAM managed policy ARN to a permission set.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.attach_managed_policy_to_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#attach_managed_policy_to_permission_set)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.can_paginate)
+        Check if an operation can be paginated.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#can_paginate)
         """
 
@@ -116,9 +120,12 @@ class SSOAdminClient:
         PermissionSetArn: str,
         PrincipalType: PrincipalTypeType,
         PrincipalId: str
-    ) -> CreateAccountAssignmentResponseTypeDef:
+    ) -> CreateAccountAssignmentResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.create_account_assignment)
+        Assigns access to a principal for a specified AWS account using a specified
+        permission set.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.create_account_assignment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#create_account_assignment)
         """
 
@@ -129,7 +136,10 @@ class SSOAdminClient:
         InstanceAccessControlAttributeConfiguration: "InstanceAccessControlAttributeConfigurationTypeDef"
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.create_instance_access_control_attribute_configuration)
+        Enables the attributes-based access control (ABAC) feature for the specified AWS
+        SSO instance.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.create_instance_access_control_attribute_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#create_instance_access_control_attribute_configuration)
         """
 
@@ -142,9 +152,11 @@ class SSOAdminClient:
         SessionDuration: str = None,
         RelayState: str = None,
         Tags: List["TagTypeDef"] = None
-    ) -> CreatePermissionSetResponseTypeDef:
+    ) -> CreatePermissionSetResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.create_permission_set)
+        Creates a permission set within a specified SSO instance.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.create_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#create_permission_set)
         """
 
@@ -157,9 +169,12 @@ class SSOAdminClient:
         PermissionSetArn: str,
         PrincipalType: PrincipalTypeType,
         PrincipalId: str
-    ) -> DeleteAccountAssignmentResponseTypeDef:
+    ) -> DeleteAccountAssignmentResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.delete_account_assignment)
+        Deletes a principal's access from a specified AWS account using a specified
+        permission set.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.delete_account_assignment)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#delete_account_assignment)
         """
 
@@ -167,7 +182,9 @@ class SSOAdminClient:
         self, *, InstanceArn: str, PermissionSetArn: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.delete_inline_policy_from_permission_set)
+        Deletes the inline policy from a specified permission set.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.delete_inline_policy_from_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#delete_inline_policy_from_permission_set)
         """
 
@@ -175,53 +192,71 @@ class SSOAdminClient:
         self, *, InstanceArn: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.delete_instance_access_control_attribute_configuration)
+        Disables the attributes-based access control (ABAC) feature for the specified
+        AWS SSO instance and deletes all of the attribute mappings that have been
+        configured.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.delete_instance_access_control_attribute_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#delete_instance_access_control_attribute_configuration)
         """
 
     def delete_permission_set(self, *, InstanceArn: str, PermissionSetArn: str) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.delete_permission_set)
+        Deletes the specified permission set.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.delete_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#delete_permission_set)
         """
 
     def describe_account_assignment_creation_status(
         self, *, InstanceArn: str, AccountAssignmentCreationRequestId: str
-    ) -> DescribeAccountAssignmentCreationStatusResponseTypeDef:
+    ) -> DescribeAccountAssignmentCreationStatusResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.describe_account_assignment_creation_status)
+        Describes the status of the assignment creation request.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.describe_account_assignment_creation_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#describe_account_assignment_creation_status)
         """
 
     def describe_account_assignment_deletion_status(
         self, *, InstanceArn: str, AccountAssignmentDeletionRequestId: str
-    ) -> DescribeAccountAssignmentDeletionStatusResponseTypeDef:
+    ) -> DescribeAccountAssignmentDeletionStatusResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.describe_account_assignment_deletion_status)
+        Describes the status of the assignment deletion request.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.describe_account_assignment_deletion_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#describe_account_assignment_deletion_status)
         """
 
     def describe_instance_access_control_attribute_configuration(
         self, *, InstanceArn: str
-    ) -> DescribeInstanceAccessControlAttributeConfigurationResponseTypeDef:
+    ) -> DescribeInstanceAccessControlAttributeConfigurationResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.describe_instance_access_control_attribute_configuration)
+        Returns the list of AWS SSO identity store attributes that have been configured
+        to work with attributes-based access control (ABAC) for the specified AWS SSO
+        instance.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.describe_instance_access_control_attribute_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#describe_instance_access_control_attribute_configuration)
         """
 
     def describe_permission_set(
         self, *, InstanceArn: str, PermissionSetArn: str
-    ) -> DescribePermissionSetResponseTypeDef:
+    ) -> DescribePermissionSetResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.describe_permission_set)
+        Gets the details of the permission set.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.describe_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#describe_permission_set)
         """
 
     def describe_permission_set_provisioning_status(
         self, *, InstanceArn: str, ProvisionPermissionSetRequestId: str
-    ) -> DescribePermissionSetProvisioningStatusResponseTypeDef:
+    ) -> DescribePermissionSetProvisioningStatusResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.describe_permission_set_provisioning_status)
+        Describes the status for the given permission set provisioning request.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.describe_permission_set_provisioning_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#describe_permission_set_provisioning_status)
         """
 
@@ -229,7 +264,9 @@ class SSOAdminClient:
         self, *, InstanceArn: str, PermissionSetArn: str, ManagedPolicyArn: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.detach_managed_policy_from_permission_set)
+        Detaches the attached IAM managed policy ARN from the specified permission set.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.detach_managed_policy_from_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#detach_managed_policy_from_permission_set)
         """
 
@@ -241,15 +278,19 @@ class SSOAdminClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.generate_presigned_url)
+        Generate a presigned url given a client, its method, and arguments.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#generate_presigned_url)
         """
 
     def get_inline_policy_for_permission_set(
         self, *, InstanceArn: str, PermissionSetArn: str
-    ) -> GetInlinePolicyForPermissionSetResponseTypeDef:
+    ) -> GetInlinePolicyForPermissionSetResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.get_inline_policy_for_permission_set)
+        Obtains the inline policy assigned to the permission set.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.get_inline_policy_for_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#get_inline_policy_for_permission_set)
         """
 
@@ -259,10 +300,13 @@ class SSOAdminClient:
         InstanceArn: str,
         MaxResults: int = None,
         NextToken: str = None,
-        Filter: OperationStatusFilterTypeDef = None
-    ) -> ListAccountAssignmentCreationStatusResponseTypeDef:
+        Filter: "OperationStatusFilterTypeDef" = None
+    ) -> ListAccountAssignmentCreationStatusResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignment_creation_status)
+        Lists the status of the AWS account assignment creation requests for a specified
+        SSO instance.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignment_creation_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_account_assignment_creation_status)
         """
 
@@ -272,10 +316,13 @@ class SSOAdminClient:
         InstanceArn: str,
         MaxResults: int = None,
         NextToken: str = None,
-        Filter: OperationStatusFilterTypeDef = None
-    ) -> ListAccountAssignmentDeletionStatusResponseTypeDef:
+        Filter: "OperationStatusFilterTypeDef" = None
+    ) -> ListAccountAssignmentDeletionStatusResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignment_deletion_status)
+        Lists the status of the AWS account assignment deletion requests for a specified
+        SSO instance.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignment_deletion_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_account_assignment_deletion_status)
         """
 
@@ -287,9 +334,12 @@ class SSOAdminClient:
         PermissionSetArn: str,
         MaxResults: int = None,
         NextToken: str = None
-    ) -> ListAccountAssignmentsResponseTypeDef:
+    ) -> ListAccountAssignmentsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignments)
+        Lists the assignee of the specified AWS account with the specified permission
+        set.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.list_account_assignments)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_account_assignments)
         """
 
@@ -301,17 +351,21 @@ class SSOAdminClient:
         ProvisioningStatus: ProvisioningStatusType = None,
         MaxResults: int = None,
         NextToken: str = None
-    ) -> ListAccountsForProvisionedPermissionSetResponseTypeDef:
+    ) -> ListAccountsForProvisionedPermissionSetResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.list_accounts_for_provisioned_permission_set)
+        Lists all the AWS accounts where the specified permission set is provisioned.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.list_accounts_for_provisioned_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_accounts_for_provisioned_permission_set)
         """
 
     def list_instances(
         self, *, MaxResults: int = None, NextToken: str = None
-    ) -> ListInstancesResponseTypeDef:
+    ) -> ListInstancesResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.list_instances)
+        Lists the SSO instances that the caller has access to.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.list_instances)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_instances)
         """
 
@@ -322,9 +376,11 @@ class SSOAdminClient:
         PermissionSetArn: str,
         MaxResults: int = None,
         NextToken: str = None
-    ) -> ListManagedPoliciesInPermissionSetResponseTypeDef:
+    ) -> ListManagedPoliciesInPermissionSetResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.list_managed_policies_in_permission_set)
+        Lists the IAM managed policy that is attached to a specified permission set.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.list_managed_policies_in_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_managed_policies_in_permission_set)
         """
 
@@ -334,18 +390,23 @@ class SSOAdminClient:
         InstanceArn: str,
         MaxResults: int = None,
         NextToken: str = None,
-        Filter: OperationStatusFilterTypeDef = None
-    ) -> ListPermissionSetProvisioningStatusResponseTypeDef:
+        Filter: "OperationStatusFilterTypeDef" = None
+    ) -> ListPermissionSetProvisioningStatusResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_set_provisioning_status)
+        Lists the status of the permission set provisioning requests for a specified SSO
+        instance.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_set_provisioning_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_permission_set_provisioning_status)
         """
 
     def list_permission_sets(
         self, *, InstanceArn: str, NextToken: str = None, MaxResults: int = None
-    ) -> ListPermissionSetsResponseTypeDef:
+    ) -> ListPermissionSetsResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_sets)
+        Lists the  PermissionSet s in an SSO instance.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_sets)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_permission_sets)
         """
 
@@ -357,17 +418,21 @@ class SSOAdminClient:
         ProvisioningStatus: ProvisioningStatusType = None,
         MaxResults: int = None,
         NextToken: str = None
-    ) -> ListPermissionSetsProvisionedToAccountResponseTypeDef:
+    ) -> ListPermissionSetsProvisionedToAccountResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_sets_provisioned_to_account)
+        Lists all the permission sets that are provisioned to a specified AWS account.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.list_permission_sets_provisioned_to_account)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_permission_sets_provisioned_to_account)
         """
 
     def list_tags_for_resource(
         self, *, InstanceArn: str, ResourceArn: str, NextToken: str = None
-    ) -> ListTagsForResourceResponseTypeDef:
+    ) -> ListTagsForResourceResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.list_tags_for_resource)
+        Lists the tags that are attached to a specified resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.list_tags_for_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#list_tags_for_resource)
         """
 
@@ -378,9 +443,12 @@ class SSOAdminClient:
         PermissionSetArn: str,
         TargetType: ProvisionTargetTypeType,
         TargetId: str = None
-    ) -> ProvisionPermissionSetResponseTypeDef:
+    ) -> ProvisionPermissionSetResponseResponseTypeDef:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.provision_permission_set)
+        The process by which a specified permission set is provisioned to the specified
+        target.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.provision_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#provision_permission_set)
         """
 
@@ -388,7 +456,9 @@ class SSOAdminClient:
         self, *, InstanceArn: str, PermissionSetArn: str, InlinePolicy: str
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.put_inline_policy_to_permission_set)
+        Attaches an IAM inline policy to a permission set.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.put_inline_policy_to_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#put_inline_policy_to_permission_set)
         """
 
@@ -396,7 +466,9 @@ class SSOAdminClient:
         self, *, InstanceArn: str, ResourceArn: str, Tags: List["TagTypeDef"]
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.tag_resource)
+        Associates a set of tags with a specified resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.tag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#tag_resource)
         """
 
@@ -404,7 +476,9 @@ class SSOAdminClient:
         self, *, InstanceArn: str, ResourceArn: str, TagKeys: List[str]
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.untag_resource)
+        Disassociates a set of tags from a specified resource.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.untag_resource)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#untag_resource)
         """
 
@@ -415,7 +489,10 @@ class SSOAdminClient:
         InstanceAccessControlAttributeConfiguration: "InstanceAccessControlAttributeConfigurationTypeDef"
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.update_instance_access_control_attribute_configuration)
+        Updates the AWS SSO identity store attributes to use with the AWS SSO instance
+        for attributes-based access control (ABAC).
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.update_instance_access_control_attribute_configuration)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#update_instance_access_control_attribute_configuration)
         """
 
@@ -429,7 +506,9 @@ class SSOAdminClient:
         RelayState: str = None
     ) -> Dict[str, Any]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Client.update_permission_set)
+        Updates an existing permission set.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Client.update_permission_set)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/client.html#update_permission_set)
         """
 
@@ -438,7 +517,8 @@ class SSOAdminClient:
         self, operation_name: Literal["list_account_assignment_creation_status"]
     ) -> ListAccountAssignmentCreationStatusPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentCreationStatus)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentcreationstatuspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentCreationStatus)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentcreationstatuspaginator)
         """
 
     @overload
@@ -446,7 +526,8 @@ class SSOAdminClient:
         self, operation_name: Literal["list_account_assignment_deletion_status"]
     ) -> ListAccountAssignmentDeletionStatusPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentDeletionStatus)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentdeletionstatuspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentDeletionStatus)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentdeletionstatuspaginator)
         """
 
     @overload
@@ -454,7 +535,8 @@ class SSOAdminClient:
         self, operation_name: Literal["list_account_assignments"]
     ) -> ListAccountAssignmentsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignments)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignments)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentspaginator)
         """
 
     @overload
@@ -462,13 +544,15 @@ class SSOAdminClient:
         self, operation_name: Literal["list_accounts_for_provisioned_permission_set"]
     ) -> ListAccountsForProvisionedPermissionSetPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountsForProvisionedPermissionSet)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountsforprovisionedpermissionsetpaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountsForProvisionedPermissionSet)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountsforprovisionedpermissionsetpaginator)
         """
 
     @overload
     def get_paginator(self, operation_name: Literal["list_instances"]) -> ListInstancesPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListInstances)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listinstancespaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListInstances)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listinstancespaginator)
         """
 
     @overload
@@ -476,7 +560,8 @@ class SSOAdminClient:
         self, operation_name: Literal["list_managed_policies_in_permission_set"]
     ) -> ListManagedPoliciesInPermissionSetPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListManagedPoliciesInPermissionSet)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listmanagedpoliciesinpermissionsetpaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListManagedPoliciesInPermissionSet)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listmanagedpoliciesinpermissionsetpaginator)
         """
 
     @overload
@@ -484,7 +569,8 @@ class SSOAdminClient:
         self, operation_name: Literal["list_permission_set_provisioning_status"]
     ) -> ListPermissionSetProvisioningStatusPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetProvisioningStatus)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetprovisioningstatuspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetProvisioningStatus)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetprovisioningstatuspaginator)
         """
 
     @overload
@@ -492,7 +578,8 @@ class SSOAdminClient:
         self, operation_name: Literal["list_permission_sets"]
     ) -> ListPermissionSetsPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSets)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetspaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSets)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetspaginator)
         """
 
     @overload
@@ -500,7 +587,8 @@ class SSOAdminClient:
         self, operation_name: Literal["list_permission_sets_provisioned_to_account"]
     ) -> ListPermissionSetsProvisionedToAccountPaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetsProvisionedToAccount)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetsprovisionedtoaccountpaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetsProvisionedToAccount)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetsprovisionedtoaccountpaginator)
         """
 
     @overload
@@ -508,5 +596,6 @@ class SSOAdminClient:
         self, operation_name: Literal["list_tags_for_resource"]
     ) -> ListTagsForResourcePaginator:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListTagsForResource)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listtagsforresourcepaginator)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListTagsForResource)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listtagsforresourcepaginator)
         """
