@@ -42,16 +42,16 @@ from botocore.paginate import Paginator as Boto3Paginator
 
 from .literals import ProvisioningStatusType
 from .type_defs import (
-    ListAccountAssignmentCreationStatusResponseTypeDef,
-    ListAccountAssignmentDeletionStatusResponseTypeDef,
-    ListAccountAssignmentsResponseTypeDef,
-    ListAccountsForProvisionedPermissionSetResponseTypeDef,
-    ListInstancesResponseTypeDef,
-    ListManagedPoliciesInPermissionSetResponseTypeDef,
-    ListPermissionSetProvisioningStatusResponseTypeDef,
-    ListPermissionSetsProvisionedToAccountResponseTypeDef,
-    ListPermissionSetsResponseTypeDef,
-    ListTagsForResourceResponseTypeDef,
+    ListAccountAssignmentCreationStatusResponseResponseTypeDef,
+    ListAccountAssignmentDeletionStatusResponseResponseTypeDef,
+    ListAccountAssignmentsResponseResponseTypeDef,
+    ListAccountsForProvisionedPermissionSetResponseResponseTypeDef,
+    ListInstancesResponseResponseTypeDef,
+    ListManagedPoliciesInPermissionSetResponseResponseTypeDef,
+    ListPermissionSetProvisioningStatusResponseResponseTypeDef,
+    ListPermissionSetsProvisionedToAccountResponseResponseTypeDef,
+    ListPermissionSetsResponseResponseTypeDef,
+    ListTagsForResourceResponseResponseTypeDef,
     OperationStatusFilterTypeDef,
     PaginatorConfigTypeDef,
 )
@@ -72,43 +72,46 @@ __all__ = (
 
 class ListAccountAssignmentCreationStatusPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentCreationStatus)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentcreationstatuspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentCreationStatus)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentcreationstatuspaginator)
     """
 
     def paginate(
         self,
         *,
         InstanceArn: str,
-        Filter: OperationStatusFilterTypeDef = None,
+        Filter: "OperationStatusFilterTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListAccountAssignmentCreationStatusResponseTypeDef]:
+    ) -> Iterator[ListAccountAssignmentCreationStatusResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentCreationStatus.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentCreationStatus.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentcreationstatuspaginator)
         """
 
 
 class ListAccountAssignmentDeletionStatusPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentDeletionStatus)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentdeletionstatuspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentDeletionStatus)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentdeletionstatuspaginator)
     """
 
     def paginate(
         self,
         *,
         InstanceArn: str,
-        Filter: OperationStatusFilterTypeDef = None,
+        Filter: "OperationStatusFilterTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListAccountAssignmentDeletionStatusResponseTypeDef]:
+    ) -> Iterator[ListAccountAssignmentDeletionStatusResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentDeletionStatus.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignmentDeletionStatus.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentdeletionstatuspaginator)
         """
 
 
 class ListAccountAssignmentsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignments)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignments)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentspaginator)
     """
 
     def paginate(
@@ -118,16 +121,17 @@ class ListAccountAssignmentsPaginator(Boto3Paginator):
         AccountId: str,
         PermissionSetArn: str,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListAccountAssignmentsResponseTypeDef]:
+    ) -> Iterator[ListAccountAssignmentsResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignments.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountAssignments.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountassignmentspaginator)
         """
 
 
 class ListAccountsForProvisionedPermissionSetPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountsForProvisionedPermissionSet)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountsforprovisionedpermissionsetpaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountsForProvisionedPermissionSet)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountsforprovisionedpermissionsetpaginator)
     """
 
     def paginate(
@@ -137,30 +141,32 @@ class ListAccountsForProvisionedPermissionSetPaginator(Boto3Paginator):
         PermissionSetArn: str,
         ProvisioningStatus: ProvisioningStatusType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListAccountsForProvisionedPermissionSetResponseTypeDef]:
+    ) -> Iterator[ListAccountsForProvisionedPermissionSetResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountsForProvisionedPermissionSet.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListAccountsForProvisionedPermissionSet.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listaccountsforprovisionedpermissionsetpaginator)
         """
 
 
 class ListInstancesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListInstances)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listinstancespaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListInstances)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listinstancespaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListInstancesResponseTypeDef]:
+    ) -> Iterator[ListInstancesResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListInstances.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListInstances.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listinstancespaginator)
         """
 
 
 class ListManagedPoliciesInPermissionSetPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListManagedPoliciesInPermissionSet)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listmanagedpoliciesinpermissionsetpaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListManagedPoliciesInPermissionSet)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listmanagedpoliciesinpermissionsetpaginator)
     """
 
     def paginate(
@@ -169,48 +175,51 @@ class ListManagedPoliciesInPermissionSetPaginator(Boto3Paginator):
         InstanceArn: str,
         PermissionSetArn: str,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListManagedPoliciesInPermissionSetResponseTypeDef]:
+    ) -> Iterator[ListManagedPoliciesInPermissionSetResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListManagedPoliciesInPermissionSet.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListManagedPoliciesInPermissionSet.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listmanagedpoliciesinpermissionsetpaginator)
         """
 
 
 class ListPermissionSetProvisioningStatusPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetProvisioningStatus)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetprovisioningstatuspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetProvisioningStatus)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetprovisioningstatuspaginator)
     """
 
     def paginate(
         self,
         *,
         InstanceArn: str,
-        Filter: OperationStatusFilterTypeDef = None,
+        Filter: "OperationStatusFilterTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListPermissionSetProvisioningStatusResponseTypeDef]:
+    ) -> Iterator[ListPermissionSetProvisioningStatusResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetProvisioningStatus.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetProvisioningStatus.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetprovisioningstatuspaginator)
         """
 
 
 class ListPermissionSetsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSets)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetspaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSets)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetspaginator)
     """
 
     def paginate(
         self, *, InstanceArn: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListPermissionSetsResponseTypeDef]:
+    ) -> Iterator[ListPermissionSetsResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSets.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSets.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetspaginator)
         """
 
 
 class ListPermissionSetsProvisionedToAccountPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetsProvisionedToAccount)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetsprovisionedtoaccountpaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetsProvisionedToAccount)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetsprovisionedtoaccountpaginator)
     """
 
     def paginate(
@@ -220,22 +229,23 @@ class ListPermissionSetsProvisionedToAccountPaginator(Boto3Paginator):
         AccountId: str,
         ProvisioningStatus: ProvisioningStatusType = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListPermissionSetsProvisionedToAccountResponseTypeDef]:
+    ) -> Iterator[ListPermissionSetsProvisionedToAccountResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetsProvisionedToAccount.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListPermissionSetsProvisionedToAccount.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listpermissionsetsprovisionedtoaccountpaginator)
         """
 
 
 class ListTagsForResourcePaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListTagsForResource)[Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listtagsforresourcepaginator)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListTagsForResource)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listtagsforresourcepaginator)
     """
 
     def paginate(
         self, *, InstanceArn: str, ResourceArn: str, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListTagsForResourceResponseTypeDef]:
+    ) -> Iterator[ListTagsForResourceResponseResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.101/reference/services/sso-admin.html#SSOAdmin.Paginator.ListTagsForResource.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.102/reference/services/sso-admin.html#SSOAdmin.Paginator.ListTagsForResource.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sso_admin/paginators.html#listtagsforresourcepaginator)
         """
